@@ -7,28 +7,28 @@ use winit::{
 };
 
 fn main() {
+    env_logger::init();
+
     // Initialize wgpu
     let event_loop: EventLoop<()> = EventLoop::new();
     let window = winit::window::Window::new(&event_loop).unwrap();
-    let instance = wgpu::Instance::new(wgpu::BackendBit::PRIMARY);
+    let instance = wgpu::Instance::new(wgpu::Backends::PRIMARY);
     let surface = unsafe { instance.create_surface(&window) };
     let adapter =
         futures::executor::block_on(instance.request_adapter(&Default::default())).unwrap();
     let (device, queue) =
         futures::executor::block_on(adapter.request_device(&Default::default(), None)).unwrap();
-    let swapchain_format = adapter
-        .get_swap_chain_preferred_format(&surface)
+    let swapchain_format = surface
+        .get_preferred_format(&adapter)
         .unwrap_or(wgpu::TextureFormat::Bgra8UnormSrgb);
-    let mut swap_chain = device.create_swap_chain(
-        &surface,
-        &wgpu::SwapChainDescriptor {
-            usage: wgpu::TextureUsage::RENDER_ATTACHMENT,
-            format: swapchain_format,
-            width: window.inner_size().width,
-            height: window.inner_size().height,
-            present_mode: wgpu::PresentMode::Mailbox,
-        },
-    );
+    let mut config = wgpu::SurfaceConfiguration {
+        usage: wgpu::TextureUsages::RENDER_ATTACHMENT,
+        format: swapchain_format,
+        width: window.inner_size().width,
+        height: window.inner_size().height,
+        present_mode: wgpu::PresentMode::Mailbox,
+    };
+    surface.configure(&device, &config);
 
     // Create SMAA target
     let mut smaa_target = SmaaTarget::new(
@@ -44,7 +44,6 @@ fn main() {
     let shader = device.create_shader_module(&wgpu::ShaderModuleDescriptor {
         label: None,
         source: wgpu::ShaderSource::Wgsl(Cow::Borrowed(include_str!("shader.wgsl"))),
-        flags: wgpu::ShaderFlags::all(),
     });
     let pipeline_layout = device.create_pipeline_layout(&wgpu::PipelineLayoutDescriptor {
         label: None,
@@ -78,41 +77,38 @@ fn main() {
                 ..
             } => {
                 // Recreate the swap chain with the new size
-                swap_chain = device.create_swap_chain(
-                    &surface,
-                    &wgpu::SwapChainDescriptor {
-                        usage: wgpu::TextureUsage::RENDER_ATTACHMENT,
-                        format: swapchain_format,
-                        width: size.width,
-                        height: size.height,
-                        present_mode: wgpu::PresentMode::Mailbox,
-                    },
-                );
+                config.width = size.width;
+                config.height = size.height;
+                surface.configure(&device, &config);
                 smaa_target.resize(&device, size.width, size.height);
             }
             Event::RedrawRequested(_) => {
-                let output_frame = swap_chain.get_current_frame().unwrap().output;
-                let frame = smaa_target.start_frame(&device, &queue, &output_frame.view);
-
-                let mut encoder =
-                    device.create_command_encoder(&wgpu::CommandEncoderDescriptor { label: None });
+                let output_frame = surface.get_current_texture().unwrap();
+                let output_view = output_frame.texture.create_view(&Default::default());
                 {
-                    let mut rpass = encoder.begin_render_pass(&wgpu::RenderPassDescriptor {
-                        label: None,
-                        color_attachments: &[wgpu::RenderPassColorAttachment {
-                            view: &*frame,
-                            resolve_target: None,
-                            ops: wgpu::Operations {
-                                load: wgpu::LoadOp::Clear(wgpu::Color::GREEN),
-                                store: true,
-                            },
-                        }],
-                        depth_stencil_attachment: None,
-                    });
-                    rpass.set_pipeline(&render_pipeline);
-                    rpass.draw(0..3, 0..1);
+                    let frame = smaa_target.start_frame(&device, &queue, &output_view);
+
+                    let mut encoder =
+                        device.create_command_encoder(&wgpu::CommandEncoderDescriptor { label: None });
+                    {
+                        let mut rpass = encoder.begin_render_pass(&wgpu::RenderPassDescriptor {
+                            label: None,
+                            color_attachments: &[wgpu::RenderPassColorAttachment {
+                                view: &*frame,
+                                resolve_target: None,
+                                ops: wgpu::Operations {
+                                    load: wgpu::LoadOp::Clear(wgpu::Color::GREEN),
+                                    store: true,
+                                },
+                            }],
+                            depth_stencil_attachment: None,
+                        });
+                        rpass.set_pipeline(&render_pipeline);
+                        rpass.draw(0..3, 0..1);
+                    }
+                    queue.submit(Some(encoder.finish()));
                 }
-                queue.submit(Some(encoder.finish()));
+                output_frame.present();
             }
             Event::WindowEvent {
                 event: WindowEvent::CloseRequested,
